==> atlassian_connect_models-0.0.1.tar.gz: lib/src/descriptor/bitbucket/bitbucket_descriptor_model.dart <==
library ac_dart.descriptor_model.bitbucket;

import 'dart:convert';

import 'scopes.dart';
import 'package:atlassian_connect_models/src/descriptor/descriptor_model.dart';
import 'package:constrain/constrain.dart';
import 'package:option/option.dart';
import 'package:quiver/iterables.dart';
import 'package:stuff/stuff.dart';

class _ProductlessScope extends Scope implements BitbucketScope {
  _ProductlessScope(String key) : super(key);
}

class BitbucketConnectAddon
    extends ConnectAddon<BitbucketModuleList, BitbucketScope> {
  BitbucketConnectAddon(
      {String key,
      String name,
      String description,
      BitbucketModuleList modules,
      Uri baseUrl,
      String baseUrlStr,
      Authentication authentication,
      Lifecycle lifecycle,
      Vendor vendor,
      Iterable<BitbucketScope> scopes})
      : super(
            key: key,
            name: name,
            description: description,
            modules: modules,
            baseUrl: baseUrl,
            baseUrlStr: baseUrlStr,
            authentication: authentication,
            lifecycle: lifecycle,
            vendor: vendor,
            scopes: scopes);

  BitbucketConnectAddon.fromJson(Map json)
      : super.fromJson(json, (Map j) => new BitbucketModuleList.fromJson(j),
            (String s) => new _ProductlessScope(s));

//  Map toJson() => super.toJson();

  String toString() => JSON.encode(this);
}

class BitbucketModuleTypes {
  static const String repoPage = 'repoPage';
}

bool _oauthConsumerMandatoryForBitbucket(Option<OAuthConsumer> consumer) =>
    consumer is Some;

class BitbucketModuleList extends CoreModuleList {
  Iterable<Page> get repoPages => filtered(BitbucketModuleTypes.repoPage);
  @Ensure(_oauthConsumerMandatoryForBitbucket,
      description: 'oauth consumer is mandatory for bitbucket')
  Option<OAuthConsumer> get oauthConsumer => super.oauthConsumer;

  BitbucketModuleList(
      {Iterable<Page> generalPages: const [],
      Iterable<Page> adminPages: const [],
      Iterable<WebItem> webItems: const [],
      Page configurePage,
      Iterable<Webhook> webhooks: const [],
      OAuthConsumer oauthConsumer,
      Iterable<Page> repoPages})
      : super.fromModules(concat([
          CoreModuleList.createCoreModules(generalPages, adminPages, webItems,
              configurePage, webhooks, oauthConsumer),
          BaseModuleList.mapModules(repoPages, BitbucketModuleTypes.repoPage)
        ]));

  BitbucketModuleList.fromModules(Iterable<ClassifiedModule> modules)
      : super.fromModules(modules);

  BitbucketModuleList.fromCore(
      {CoreModuleList coreModules, Iterable<Page> repoPages})
      : super.fromModules(concat([
          coreModules.modules,
          BaseModuleList.mapModules(repoPages, BitbucketModuleTypes.repoPage)
        ]));

  factory BitbucketModuleList.fromJson(Map json) {
    final p = parseJson(json);
    return new BitbucketModuleList(
        generalPages: p.list('generalPage', (v) => new Page.fromJson(v)),
        adminPages: p.list('adminPage', (v) => new Page.fromJson(v)),
        repoPages: p.list('repoPage', (v) => new Page.fromJson(v)),
        webItems: p.list('webItem', (v) => new WebItem.fromJson(v)),
        webhooks: p.list('webhook', (v) => new Webhook.fromJson(v)),
        configurePage: p.single('configurePage', (v) => new Page.fromJson(v)));
  }

  Map toJson() => (buildJson
    ..addAll(super.toJson())
    ..add('repoPage', repoPages)).json;
}

==> atlassian_connect_models-0.0.2.tar.gz: lib/src/descriptor/bitbucket/bitbucket_descriptor_model.dart <==
library ac_dart.descriptor_model.bitbucket;

import 'dart:convert';

import 'scopes.dart';
import 'package:atlassian_connect_models/src/descriptor/descriptor_model.dart';
import 'package:constrain/constrain.dart';
import 'package:option/option.dart';
import 'package:quiver/iterables.dart';
import 'package:stuff/stuff.dart';

class _ProductlessScope extends Scope implements BitbucketScope {
  _ProductlessScope(String key) : super(key);
}

class BitbucketConnectAddon
    extends ConnectAddon<BitbucketModuleList, BitbucketScope> {
  BitbucketConnectAddon(
      {String key,
      String name,
      String description,
      BitbucketModuleList modules,
      Uri baseUrl,
      String baseUrlStr,
      Authentication authentication,
      Lifecycle lifecycle,
      Vendor vendor,
      Iterable<BitbucketScope> scopes})
      : super(
            key: key,
            name: name,
            description: description,
            modules: modules,
            baseUrl: baseUrl,
            baseUrlStr: baseUrlStr,
            authentication: authentication,
            lifecycle: lifecycle,
            vendor: vendor,
            scopes: scopes);

  BitbucketConnectAddon.fromJson(Map json)
      : super.fromJson(json, (Map j) => new BitbucketModuleList.fromJson(j),
            (String s) => new _ProductlessScope(s));

//  Map toJson() => super.toJson();

  String toString() => JSON.encode(this);
}

class BitbucketModuleTypes {
  static const String repoPage = 'repoPage';
}

bool _oauthConsumerMandatoryForBitbucket(Option<OAuthConsumer> consumer) =>
    consumer is Some;

class BitbucketModuleList extends CoreModuleList {
  Iterable<Page> get repoPages => filtered(BitbucketModuleTypes.repoPage);
  @Ensure(_oauthConsumerMandatoryForBitbucket,
      description: 'oauth consumer is mandatory for bitbucket')
  Option<OAuthConsumer> get oauthConsumer => super.oauthConsumer;

  BitbucketModuleList(
      {Iterable<Page> generalPages: const [],
      Iterable<Page> adminPages: const [],
      Iterable<WebItem> webItems: const [],
      Iterable<WebPanel> webPanels: const [],
      Page configurePage,
      Iterable<Webhook> webhooks: const [],
      OAuthConsumer oauthConsumer,
      Iterable<Page> repoPages})
      : super.fromModules(concat([
          CoreModuleList.createCoreModules(generalPages, adminPages, webItems,
              webPanels, configurePage, webhooks, oauthConsumer),
          BaseModuleList.mapModules(repoPages, BitbucketModuleTypes.repoPage)
        ]));

  BitbucketModuleList.fromModules(Iterable<ClassifiedModule> modules)
      : super.fromModules(modules);

  BitbucketModuleList.fromCore(
      {CoreModuleList coreModules, Iterable<Page> repoPages})
      : super.fromModules(concat([
          coreModules.modules,
          BaseModuleList.mapModules(repoPages, BitbucketModuleTypes.repoPage)
        ]));

  factory BitbucketModuleList.fromJson(Map json) {
    final p = parseJson(json);
    return new BitbucketModuleList(
        generalPages: p.list('generalPage', (v) => new Page.fromJson(v)),
        adminPages: p.list('adminPage', (v) => new Page.fromJson(v)),
        repoPages: p.list('repoPage', (v) => new Page.fromJson(v)),
        webItems: p.list('webItem', (v) => new WebItem.fromJson(v)),
        webhooks: p.list('webhook', (v) => new Webhook.fromJson(v)),
        configurePage: p.single('configurePage', (v) => new Page.fromJson(v)));
  }

  Map toJson() => (buildJson
        ..addAll(super.toJson())
        ..add('repoPage', repoPages))
      .json;
}
